AreaQualification

Enum AreaQualification 

pub enum AreaQualification {
    UnprotectedUnguarded = 0,
    ProtectedGuarded = 1,
    GraphicCharacterInput = 2,
    NumericInput = 3,
    AlphabeticInput = 4,
    InputAlignedRight = 5,
    FillZeros = 6,
    SetCharacterTabulationStop = 7,
    ProtectedUnguarded = 8,
    FillSpaces = 9,
    InputAlignedLeft = 10,
    Reversed = 11,
}
Valid parameter values to the function DAQ.

Variants



UnprotectedUnguarded = 0

Unprotected and unguarded.



ProtectedGuarded = 1

Protected and guarded.



GraphicCharacterInput = 2

Graphic character input.



NumericInput = 3

Numeric input.



AlphabeticInput = 4

Alphabetic input.



InputAlignedRight = 5

Input aligned on the last character position of the qualified area.



FillZeros = 6

Fill with ZEROs.



SetCharacterTabulationStop = 7

Set a character tabulation stop at the active presentation position (the first character position of the qualified area) to indicate the beginning of a field.



ProtectedUnguarded = 8

Protected and unguarded



FillSpaces = 9

Fill with SPACEs



InputAlignedLeft = 10

Input aligned on the first character position of the qualified area.



Reversed = 11

The order of the character positions in the input field is reserved, i.e. the last position in each line becomes the first and vice versa; input begins at the new first position.