pub enum ClearTabulation {
CharacterTabulationStopActivePosition = 0,
LineTabulationStopActiveLine = 1,
AllCharacterTabulationStopsActiveLine = 2,
AllCharacterTabulationStops = 3,
AllLineTabulationStops = 4,
AllTabulationStops = 5,
}Expand description
Valid parameter values to the function TBC.
Variants
CharacterTabulationStopActivePosition = 0
Clear the character tabulation stop at the active presentation position.
LineTabulationStopActiveLine = 1
Clear the line tabulation stop at the active line.
AllCharacterTabulationStopsActiveLine = 2
Clear all character tabulation stops at the active line.
AllCharacterTabulationStops = 3
Clear all character tabulation stops.
AllLineTabulationStops = 4
Clear all line tabulation stops.
AllTabulationStops = 5
Clear all tabulation stops.