DeviceStatusReport

Enum DeviceStatusReport 

pub enum DeviceStatusReport {
    Ready = 0,
    BusyRepeat = 1,
    BusyLater = 2,
    MalfunctionRepeat = 3,
    MalfunctionLater = 4,
    RequestDeviceStatusReport = 5,
    RequestActivePositionReport = 6,
}
Valid parameter values to the function DSR.

Variants



Ready = 0

The device is ready, no malfunction detected



BusyRepeat = 1

The device is busy, another DSR must be requested later.



BusyLater = 2

The device is busy, another DSR will be sent later.



MalfunctionRepeat = 3

Some malfunction detected, another DSR must be requested later.



MalfunctionLater = 4

Some malfunction detected, another DSR will be sent later.



RequestDeviceStatusReport = 5

A device status report is requested.



RequestActivePositionReport = 6

A report of the active presentation position or of the active data position in the form of ACTIVE POSITION REPORT (CPR) is requested.