pub enum EraseField {
ActivePositionToEnd = 0,
BeginToActivePosition = 1,
BeginToEnd = 2,
}Expand description
Valid parameter values to the function EF.
Variants
ActivePositionToEnd = 0
Erase from the active position until the end of the field.
BeginToActivePosition = 1
Erase from the beginning of the field until (including) the active position.
BeginToEnd = 2
Erase all contents from the beginning of the field until the end of the field.