GraphicCharacterCombination

Enum GraphicCharacterCombination 

pub enum GraphicCharacterCombination {
    CombineTwo = 0,
    StartOfCombination = 1,
    EndOfCombination = 2,
}
Valid parameter values to the function GCC.

Variants



CombineTwo = 0

Combine the following two graphic characters into a single graphic symbol.



StartOfCombination = 1

Combine all following graphic characters, until the occurrence of GraphicCharacterCombination::EndOfCombination into a single graphic symbol.



EndOfCombination = 2

Combine all preceding graphic characters, starting from GraphicCharacterCombination::StartOfCombination, into a single graphic symbol.