pub enum MovementDirection {
Normal = 0,
Opposite = 1,
}Expand description
Valid parameter values to the function SIMD.
Variants
Normal = 0
The direction of implicit movement is the same as that of the character progression.
Opposite = 1
The direction of implicit movement is opposite to that of the character progression.