pub enum ParallelText {
End = 0,
BeginPrincipal = 1,
BeginSupplementary = 2,
BeginJapanesePhonetic = 3,
BeginChinesePhonetic = 4,
EndPhonetic = 5,
}Expand description
Valid parameter values to the function PTX.
Variants
End = 0
End of parallel texts.
BeginPrincipal = 1
Beginning of a string of principal parallel text.
BeginSupplementary = 2
Beginning of a string of supplementary parallel text.
BeginJapanesePhonetic = 3
Beginning of a string of supplementary Japanese phonetic annotation
BeginChinesePhonetic = 4
Beginning of a string of supplementary Chinese phonetic annotation
EndPhonetic = 5
End of a string of supplementary phonetic annotations