pub enum TabulationControl {
SetCharacterTabulationStop = 0,
SetLineTabulationStop = 1,
ClearCharacterTabulationStop = 2,
ClearLineTabulationStop = 3,
ClearCharacterTabulationStopsInLine = 4,
ClearAllCharacterTabulationStops = 5,
ClearAllLineTabulationStops = 6,
}Expand description
Valid parameter values to the function CTC.
Variants
SetCharacterTabulationStop = 0
A character tabulation stop is set at the active presentation position.
SetLineTabulationStop = 1
A line tabulation stop is set at the active line (the line that contains the active presentation position).
ClearCharacterTabulationStop = 2
The character tabulation stop at the active presentation position is cleared.
ClearLineTabulationStop = 3
The line tabulation stop at the active line is cleared.
ClearCharacterTabulationStopsInLine = 4
All character tabulation stops in the active line are cleared.
ClearAllCharacterTabulationStops = 5
All character tabulation stops are cleared.
ClearAllLineTabulationStops = 6
All line tabulation stops are cleared.