pub fn FNK(n: u32) -> ControlFunction<'static>Expand description
Function Key.
FNK is a control function in which the parameter value identifies the function key which has been operated.
pub fn FNK(n: u32) -> ControlFunction<'static>Function Key.
FNK is a control function in which the parameter value identifies the function key which has been operated.