MC

Function MC 

pub fn MC(s: Option<MediaCopy>) -> ControlFunction<'static>
Media Copy.

MC is used either to initiate a transfer of data from or to an auxiliary input/output device or to enable or disable the relay of the received data stream to an auxiliary input/output device, depending on the parameter value.

The default value for s is MediaCopy::BeginTransferToPrimary.