SCP

Function SCP 

pub fn SCP(s: CharacterPath, t: CharacterPathScope) -> ControlFunction<'static>
Select Character Path.

SCP is used to select the character path, relative to the line orientation, for the active line (the line that contains the active presentation position) and subsequent lines in the presentation component. It is also used to update the content of the active line in the presentation component and the content of the active line (the line that contains the active data position) in the data component. This takes effect immediately.