SDS

Function SDS 

pub fn SDS(s: Option<StringDirection>) -> ControlFunction<'static>
Start Directed String.

SDS is used to establish in the data component the beginning and end of a string of characters as well as the direction of the string. This direction may be different from that currently established. The indicated string follows the preceding text. The established character progression is not affected.

The beginning of a directed string is indicated by SDS with a parameter value not equal to StringDirection::End. A directed string may contain one or more nested strings. These nested strings may be directed strings the beginning of which are indicated by SDS with a parameter value not equal to StringDirection::End, or reversed stings the beginning of which are indicated by START REVERSED STRING (SRS) with a parameter value of ReversedString::Start. Every beginning of such a string invokes the next deeper level of nesting.

The standard does not define the location of the active data position within any such nested string.

The end of a directed string is indicated by SDS with a parameter value of StringDirection::End. Every such end of such a string re-establishes the next higher level of nesting (the one in effect prior to the string just ended). The direction is re-established to that in effect prior to the string just ended. The active data position is moved to the character position following the characters of the string just ended.

The default value of s is StringDirection::End.

Note 1

The effect of receiving a CVT, HT, SCP, SPD, or VT control function within an SDS string is not defined.

Note 2

The control functions for area definitions (DAQ, EPA, SPA, SSA) should not be used within an SDS string.