pub struct ControlFunction<'a> { /* private fields */ }Expand description
An ansi control function defined in ECMA-48.
This struct implements the PartialEq trait for String-like types (all types that implement AsRef<str>).
It can be used to compare ControlFunctions with string-like values using == or != functions.
Example:
use ansi_control_codes::c0;
let some_string = String::from("\u{001B}");
if (c0::ESC == some_string) {
println!("ESC!")
}Implementations
Sourceimpl<'a> ControlFunction<'a>
impl<'a> ControlFunction<'a>
Sourcepub fn private_use(
value: &'a str,
parameters: Vec<String>,
) -> Result<Self, InvalidControlFunction>
pub fn private_use( value: &'a str, parameters: Vec<String>, ) -> Result<Self, InvalidControlFunction>
Creates a new control function representing a control sequence that is declared as private use.
These functions are not standardized and their function is unknown. Yet, the standard allows these functions to exist for experimental use.
If the specified value lies outside of the valid private use area, this function will return Err.