pub enum EditingExtend {
ActivePage = 0,
ActiveLine = 1,
ActiveField = 2,
QualifiedArea = 3,
All = 4,
}Expand description
Valid parameter values to the function SEE.
Variants
ActivePage = 0
The shifted part is limited to the active page in the presentation component.
ActiveLine = 1
The shifted part is limited to the active line in the presentation component.
ActiveField = 2
The shifted part is limited to the active field in the presentation component.
QualifiedArea = 3
The shifted part is limited to the active qualified area.
All = 4
The shifted part consists of the relevant part of the entire presentation component.