pub fn DA(s: Option<DeviceAttributes>) -> ControlFunction<'static>Expand description
Device Attributes.
With a parameter DeviceAttributes::Identify (not equal to 0), DA is used to identify the device which sends
the DA. The parameter value is a device type identification code according to a register which is to be
established.
If the parameter value is DeviceAttributes::Request, DA is used to request an identifying DA from a device.
Default value for s is DeviceAttributes::Request.