pub fn DAQ(s: Option<AreaQualification>) -> ControlFunction<'static>Expand description
Define Area Qualification.
DAQ is used to indicate that the active presentation position in the presentation component is the first character
position of a qualified area. The last character position of the qualified area is the character position in the
presentation component immediately preceding the first character position of the following qualified area.
The control function operates independently of the setting of the TABULATION STOP MODE (TSM).
The character tabulation stop set by parameter value AreaQualification::SetCharacterTabulationStop applies to
the active line only.
The default value for s is `AreaQualification::UnprotectedUnguarded.
Note
The control functions for area definitions (DAQ, EPA, ESA,
SPA, SSA) should not be used within an SRS string or an SDS string.