pub fn IGS(n: u32) -> ControlFunction<'static>Expand description
Identify Graphic Subrepertoire.
IGS is used to indicate that a repertoire of the graphic characters of ISO/IEC 10367 is used in the subsequent
text.
The parameter value of IGS identifies a graphic character repertoire registered in accordance with ISO/IEC 7350.