pub fn SEE(s: Option<EditingExtend>) -> ControlFunction<'static>Expand description
Select Editing Extent.
SEE is used to establish the editing extent for subsequent character or line insertion or deletion. The
established extent remains in effect until the next occurrence of SEE in the data stream. The editing extend
depends on the parameter value.
The default value for s is EditingExtend::ActivePage.