pub fn SEF(l: Option<Load>, s: Option<Stack>) -> ControlFunction<'static>Expand description
Sheet Eject And Feed.
SEF causes a sheet of paper to be ejected from a printing device into a specified output stacker and another
sheet to be loaded into the printing device from a specified paper bin.
The default value for l is Load::None.
The default value for s is Stack::None.