pub fn TSR(n: u32) -> ControlFunction<'static>Expand description
Tabulation Stop Remove.
TSR causes any character tabulation stop at character position n in the active line (the line that contains the
active presentation position) and lines of subsequent text in the presentation component to be cleared, but does
not affect other tabulation stops.